@@ -3,7 +3,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis-python
 #
-# Most of this work is copyright (C) 2013-2016 David R. MacIver
+# Most of this work is copyright (C) 2013-2017 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -17,22 +17,28 @@
 
 # -*- coding: utf-8 -*-
 
+from __future__ import division, print_function, absolute_import
+
 # on_rtd is whether we are on readthedocs.org
 import os
 import sys
+import datetime
+
+from hypothesis import __version__
+
 on_rtd = os.environ.get('READTHEDOCS', None) == 'True'
 
 sys.path.append(
-    os.path.join(os.path.dirname(__file__), "..", "src")
+    os.path.join(os.path.dirname(__file__), '..', 'src')
 )
 
-from hypothesis import __version__
-
 
 autodoc_member_order = 'bysource'
 
 extensions = [
     'sphinx.ext.autodoc',
+    'sphinx.ext.doctest',
+    'sphinx.ext.extlinks',
     'sphinx.ext.viewcode',
     'sphinx.ext.intersphinx',
 ]
@@ -46,7 +52,7 @@ master_doc = 'index'
 
 # General information about the project.
 project = u'Hypothesis'
-copyright = u'2015, David R. MacIver'
+copyright = u'2013-%s, David R. MacIver' % datetime.datetime.utcnow().year
 author = u'David R. MacIver'
 
 version = __version__
@@ -61,9 +67,33 @@ pygments_style = 'sphinx'
 todo_include_todos = False
 
 intersphinx_mapping = {
-    'python': ('http://docs.python.org/', None),
+    'python': ('http://docs.python.org/3/', None),
 }
 
+autodoc_mock_imports = ['numpy']
+
+doctest_global_setup = '''
+# Some standard imports
+from hypothesis import *
+from hypothesis.strategies import *
+# Ensure that output (including from strategies) is deterministic
+import random
+random.seed(0)
+# don't save examples
+settings.register_profile('doctests', settings(database=None, strict=True))
+settings.load_profile('doctests')
+'''
+
+# This config value must be a dictionary of external sites, mapping unique
+# short alias names to a base URL and a prefix.
+# See http://sphinx-doc.org/ext/extlinks.html
+extlinks = {
+    'commit': ('https://github.com/HypothesisWorks/hypothesis-python/commit/%s', 'commit '),
+    'gh-file': ('https://github.com/HypothesisWorks/hypothesis-python/blob/master/%s', ''),
+    'gh-link': ('https://github.com/HypothesisWorks/hypothesis-python/%s', ''),
+    'issue': ('https://github.com/HypothesisWorks/hypothesis-python/issues/%s', 'issue #'),
+    'pull': ('https://github.com/HypothesisWorks/hypothesis-python/pulls/%s', 'pull request #'),
+}
 
 # -- Options for HTML output ----------------------------------------------
 
