@@ -3,7 +3,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis-python
 #
-# Most of this work is copyright (C) 2013-2016 David R. MacIver
+# Most of this work is copyright (C) 2013-2017 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -17,15 +17,19 @@
 
 from __future__ import division, print_function, absolute_import
 
+import os
+import sys
+import inspect
 import warnings
 from tempfile import mkdtemp
+
 import unicodenazi
+from hypothesis import settings
+from hypothesis.configuration import set_hypothesis_home_dir
 
 warnings.filterwarnings('error', category=UnicodeWarning)
 unicodenazi.enable()
 
-from hypothesis import settings
-from hypothesis.configuration import set_hypothesis_home_dir
 
 set_hypothesis_home_dir(mkdtemp())
 
@@ -36,23 +40,19 @@ settings.register_profile(
 )
 settings.load_profile('default')
 
-import inspect
-import os
-
 
 TESTS = [
     'test_testdecorators',
 ]
 
-import sys
 sys.path.append(os.path.join(
-    os.path.dirname(__file__), "..", "tests", "cover",
+    os.path.dirname(__file__), '..', 'tests', 'cover',
 ))
 
 if __name__ == '__main__':
     for t in TESTS:
         module = __import__(t)
         for k, v in sorted(module.__dict__.items(), key=lambda x: x[0]):
-            if k.startswith("test_") and inspect.isfunction(v):
+            if k.startswith('test_') and inspect.isfunction(v):
                 print(k)
                 v()
