@@ -3,7 +3,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis-python
 #
-# Most of this work is copyright (C) 2013-2016 David R. MacIver
+# Most of this work is copyright (C) 2013-2017 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -36,6 +36,25 @@ def test_prints_on_failure():
     def test(data):
         x = data.draw(st.lists(st.integers(), min_size=1))
         y = data.draw(st.sampled_from(x))
+        x.remove(y)
+        if y in x:
+            raise ValueError()
+
+    with raises(ValueError):
+        with capture_out() as out:
+            with reporting.with_reporter(reporting.default):
+                test()
+    result = out.getvalue()
+    assert 'Draw 1: [0, 0]' in result
+    assert 'Draw 2: 0' in result
+
+
+def test_prints_labels_if_given_on_failure():
+    @given(st.data())
+    def test(data):
+        x = data.draw(st.lists(st.integers(), min_size=1),
+                      label='Some numbers')
+        y = data.draw(st.sampled_from(x), label='A number')
         assert y in x
         x.remove(y)
         assert y not in x
@@ -45,8 +64,8 @@ def test_prints_on_failure():
             with reporting.with_reporter(reporting.default):
                 test()
     result = out.getvalue()
-    assert 'Draw 1: [0, 0]' in result
-    assert 'Draw 2: 0' in result
+    assert 'Draw 1 (Some numbers): [0, 0]' in result
+    assert 'Draw 2 (A number): 0' in result
 
 
 def test_given_twice_is_same():
