@@ -3,7 +3,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis-python
 #
-# Most of this work is copyright (C) 2013-2016 David R. MacIver
+# Most of this work is copyright (C) 2013-2017 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -18,21 +18,22 @@
 from __future__ import division, print_function, absolute_import
 
 import time
+from random import seed as seed_random
 from random import Random
 
 from hypothesis import strategies as st
-from hypothesis import given, Phase, settings
+from hypothesis import Phase, given, settings
 from hypothesis.database import ExampleDatabase
 from hypothesis.internal.compat import hbytes, int_from_bytes, \
     bytes_from_list
-from hypothesis.internal.conjecture.data import Status, TestData
-from hypothesis.internal.conjecture.engine import TestRunner
+from hypothesis.internal.conjecture.data import Status, ConjectureData
+from hypothesis.internal.conjecture.engine import ConjectureRunner
 
 MAX_SHRINKS = 2000
 
 
 def run_to_buffer(f):
-    runner = TestRunner(f, settings=settings(
+    runner = ConjectureRunner(f, settings=settings(
         max_examples=5000, max_iterations=10000, max_shrinks=MAX_SHRINKS,
         buffer_size=1024,
         database=None,
@@ -110,15 +111,6 @@ def zero_dist(random, n):
     return hbytes(n)
 
 
-def test_distribution_may_be_ignored():
-    @run_to_buffer
-    def x(data):
-        t = data.draw_bytes(5, zero_dist)
-        if all(t) and 255 in t:
-            data.mark_interesting()
-    assert x == hbytes([1] * 4 + [255])
-
-
 def test_can_load_data_from_a_corpus():
     key = b'hi there'
     db = ExampleDatabase()
@@ -128,7 +120,7 @@ def test_can_load_data_from_a_corpus():
     def f(data):
         if data.draw_bytes(len(value)) == value:
             data.mark_interesting()
-    runner = TestRunner(
+    runner = ConjectureRunner(
         f, settings=settings(database=db), database_key=key)
     runner.run()
     assert runner.last_data.status == Status.INTERESTING
@@ -141,12 +133,12 @@ def test_terminates_shrinks():
 
     def tf(data):
         x = hbytes(data.draw_bytes(100))
-        if sum(x) >= 500:
+        if sum(x) >= 5000:
             shrinks[0] += 1
             data.mark_interesting()
-    runner = TestRunner(tf, settings=settings(
+    runner = ConjectureRunner(tf, settings=settings(
         max_examples=5000, max_iterations=10000, max_shrinks=10,
-        database=None,
+        database=None, timeout=-1
     ))
     runner.run()
     assert runner.last_data.status == Status.INTERESTING
@@ -165,7 +157,7 @@ def test_detects_flakiness():
         if not failed_once[0]:
             failed_once[0] = True
             data.mark_interesting()
-    runner = TestRunner(tf)
+    runner = ConjectureRunner(tf)
     runner.run()
     assert count == [2]
 
@@ -187,7 +179,7 @@ def test_variadic_draw():
     def b(data):
         if any(all(d) for d in draw_list(data)):
             data.mark_interesting()
-    l = draw_list(TestData.for_buffer(b))
+    l = draw_list(ConjectureData.for_buffer(b))
     assert len(l) == 1
     assert len(l[0]) == 1
 
@@ -207,7 +199,7 @@ def test_can_navigate_to_a_valid_example():
         i = int_from_bytes(data.draw_bytes(2))
         data.draw_bytes(i)
         data.mark_interesting()
-    runner = TestRunner(f, settings=settings(
+    runner = ConjectureRunner(f, settings=settings(
         max_examples=5000, max_iterations=10000,
         buffer_size=2,
         database=None,
@@ -231,7 +223,7 @@ def test_stops_after_max_iterations_when_generating():
         seen.append(data.draw_bytes(len(value)))
         data.mark_invalid()
 
-    runner = TestRunner(f, settings=settings(
+    runner = ConjectureRunner(f, settings=settings(
         max_examples=1, max_iterations=max_iterations,
         database=db,
     ), database_key=key)
@@ -254,7 +246,7 @@ def test_stops_after_max_iterations_when_reading():
         seen.append(data.draw_bytes(1))
         data.mark_invalid()
 
-    runner = TestRunner(f, settings=settings(
+    runner = ConjectureRunner(f, settings=settings(
         max_examples=1, max_iterations=max_iterations,
         database=db,
     ), database_key=key)
@@ -274,7 +266,7 @@ def test_stops_after_max_examples_when_reading():
     def f(data):
         seen.append(data.draw_bytes(1))
 
-    runner = TestRunner(f, settings=settings(
+    runner = ConjectureRunner(f, settings=settings(
         max_examples=1,
         database=db,
     ), database_key=key)
@@ -288,7 +280,7 @@ def test_stops_after_max_examples_when_generating():
     def f(data):
         seen.append(data.draw_bytes(1))
 
-    runner = TestRunner(f, settings=settings(
+    runner = ConjectureRunner(f, settings=settings(
         max_examples=1,
         database=None,
     ))
@@ -297,7 +289,7 @@ def test_stops_after_max_examples_when_generating():
 
 
 @given(st.random_module())
-@settings(max_shrinks=0, timeout=3, min_satisfying_examples=1)
+@settings(max_shrinks=0, timeout=120, min_satisfying_examples=1)
 def test_interleaving_engines(rnd):
     @run_to_buffer
     def x(data):
@@ -311,7 +303,7 @@ def test_interleaving_engines(rnd):
                     d2.mark_interesting()
                 if 0 in result:
                     d2.mark_invalid()
-        runner = TestRunner(g, random=rnd)
+        runner = ConjectureRunner(g, random=rnd)
         runner.run()
         if runner.last_data.status == Status.INTERESTING:
             data.mark_interesting()
@@ -325,7 +317,8 @@ def test_run_with_timeout_while_shrinking():
         if any(x):
             data.mark_interesting()
 
-    runner = TestRunner(f, settings=settings(database=None, timeout=0.2,))
+    runner = ConjectureRunner(
+        f, settings=settings(database=None, timeout=0.2,))
     start = time.time()
     runner.run()
     assert time.time() <= start + 1
@@ -336,7 +329,8 @@ def test_run_with_timeout_while_boring():
     def f(data):
         time.sleep(0.1)
 
-    runner = TestRunner(f, settings=settings(database=None, timeout=0.2,))
+    runner = ConjectureRunner(
+        f, settings=settings(database=None, timeout=0.2,))
     start = time.time()
     runner.run()
     assert time.time() <= start + 1
@@ -350,7 +344,8 @@ def test_max_shrinks_can_disable_shrinking():
         seen.add(hbytes(data.draw_bytes(32)))
         data.mark_interesting()
 
-    runner = TestRunner(f, settings=settings(database=None, max_shrinks=0,))
+    runner = ConjectureRunner(
+        f, settings=settings(database=None, max_shrinks=0,))
     runner.run()
     assert len(seen) == 1
 
@@ -362,7 +357,7 @@ def test_phases_can_disable_shrinking():
         seen.add(hbytes(data.draw_bytes(32)))
         data.mark_interesting()
 
-    runner = TestRunner(f, settings=settings(
+    runner = ConjectureRunner(f, settings=settings(
         database=None, phases=(Phase.reuse, Phase.generate),
     ))
     runner.run()
@@ -382,7 +377,7 @@ def test_saves_data_while_shrinking():
             seen.add(hbytes(x))
         if hbytes(x) in seen:
             data.mark_interesting()
-    runner = TestRunner(
+    runner = ConjectureRunner(
         f, settings=settings(database=db), database_key=key)
     runner.run()
     assert runner.last_data.status == Status.INTERESTING
@@ -436,54 +431,92 @@ def test_garbage_collects_the_database():
     seen = set()
     go = True
 
+    counter = [0]
+
     def f(data):
+        """This function is designed to shrink very badly.
+
+        So we only occasionally mark things as interesting, and require
+        a certain amount of complexity to do so.
+
+        """
         x = hbytes(data.draw_bytes(512))
         if not go:
             return
-        if sum(x) >= 5000 and len(seen) < n:
+        if counter[0] % 10 == 0 and len(seen) < n and sum(x) > 1000:
             seen.add(x)
+        counter[0] += 1
         if x in seen:
             data.mark_interesting()
-    runner = TestRunner(
-        f, settings=settings(database=db, max_shrinks=2 * n), database_key=key)
+
+    local_settings = settings(database=db, max_shrinks=2 * n, timeout=-1)
+
+    runner = ConjectureRunner(f, settings=local_settings, database_key=key)
     runner.run()
     assert runner.last_data.status == Status.INTERESTING
     assert len(seen) == n
     assert set(db.fetch(key)) == seen
     go = False
-    runner = TestRunner(
-        f, settings=settings(database=db, max_shrinks=2 * n), database_key=key)
+    runner = ConjectureRunner(f, settings=local_settings, database_key=key)
     runner.run()
     assert 0 < len(set(db.fetch(key))) < n
 
 
-def test_variable_replacement():
-    @run_to_buffer
-    def x(data):
-        for _ in range(5):
-            data.start_example()
-            c = 0
-            while True:
-                d = data.draw_bytes(1)[0]
-                if not d:
-                    break
-                c += d
-            data.stop_example()
-            if c < 1000:
-                data.mark_invalid()
-        data.mark_interesting()
-    assert x == x[:x.index(0) + 1] * 5
-
-
 @given(st.randoms(), st.random_module())
+@settings(max_shrinks=0)
 def test_maliciously_bad_generator(rnd, seed):
-    rnd = Random()
-
     @run_to_buffer
     def x(data):
-        for _ in range(rnd.randint(0, 100)):
-            data.draw_bytes(rnd.randint(0, 10))
+        for _ in range(rnd.randint(1, 100)):
+            data.draw_bytes(rnd.randint(1, 10))
         if rnd.randint(0, 1):
             data.mark_invalid()
         else:
             data.mark_interesting()
+
+
+@given(st.random_module())
+def test_lot_of_dead_nodes(rnd):
+    @run_to_buffer
+    def x(data):
+        for i in range(5):
+            if data.draw_bytes(1)[0] != i:
+                data.mark_invalid()
+        data.mark_interesting()
+    assert x == hbytes([0, 1, 2, 3, 4])
+
+
+def test_one_dead_branch():
+    seed_random(0)
+    seen = set()
+
+    @run_to_buffer
+    def x(data):
+        i = data.draw_bytes(1)[0]
+        if i > 0:
+            data.mark_invalid()
+        i = data.draw_bytes(1)[0]
+        if len(seen) < 255:
+            seen.add(i)
+        elif i not in seen:
+            data.mark_interesting()
+
+
+def test_fully_exhaust_base():
+    """In this test we generate all possible values for the first byte but
+    never get to the point where we exhaust the root of the tree."""
+    seed_random(0)
+
+    seen = set()
+
+    def f(data):
+        seen.add(data.draw_bytes(2))
+
+    runner = ConjectureRunner(f, settings=settings(
+        max_examples=10000, max_iterations=10000, max_shrinks=MAX_SHRINKS,
+        buffer_size=1024,
+        database=None,
+    ))
+    runner.run()
+    assert len(seen) > 256
+    assert len({x[0] for x in seen}) == 256
