@@ -3,7 +3,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis-python
 #
-# Most of this work is copyright (C) 2013-2016 David R. MacIver
+# Most of this work is copyright (C) 2013-2017 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -51,11 +51,13 @@ def test_clears_out_database_as_things_get_boring():
     assert len(set(database.fetch(key))) > 1
     do_we_care = False
     stuff()
-    assert len(set(database.fetch(key))) > 0
+    initial = len(set(database.fetch(key)))
+    assert initial > 0
 
-    for _ in range(100):
+    for _ in range(initial):
         stuff()
-        if not set(database.fetch(key)):
+        keys = set(database.fetch(key))
+        if not keys:
             break
     else:
         assert False
