@@ -3,7 +3,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis-python
 #
-# Most of this work is copyright (C) 2013-2016 David R. MacIver
+# Most of this work is copyright (C) 2013-2017 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -26,6 +26,7 @@ import pytest
 import hypothesis.strategies as ds
 from hypothesis import find, given, settings
 from hypothesis.errors import InvalidArgument
+from hypothesis.internal.compat import float_to_decimal
 from hypothesis.internal.reflection import nicerepr
 
 
@@ -59,6 +60,15 @@ def fn_ktest(*fnkwargs):
     (ds.integers, {'min_value': 2, 'max_value': 1}),
     (ds.decimals, {'min_value': float('nan')}),
     (ds.decimals, {'min_value': 2, 'max_value': 1}),
+    (ds.decimals, {'max_value': '-snan'}),
+    (ds.decimals, {'places': -1}),
+    (ds.decimals, {'max_value': 0.0, 'min_value': 1.0}),
+    (ds.decimals, {
+        'min_value': 0.0, 'max_value': 1.0, 'allow_infinity': True}),
+    (ds.decimals, {'min_value': 'inf'}),
+    (ds.decimals, {'max_value': '-inf'}),
+    (ds.decimals, {'min_value': '-inf', 'allow_infinity': False}),
+    (ds.decimals, {'max_value': 'inf', 'allow_infinity': False}),
     (ds.fractions, {'min_value': float('nan')}),
     (ds.fractions, {'min_value': 2, 'max_value': 1}),
     (ds.fractions, {'max_denominator': 0}),
@@ -79,6 +89,9 @@ def fn_ktest(*fnkwargs):
     (ds.binary, {'max_size': 10, 'average_size': 20}),
     (ds.floats, {'min_value': float('nan')}),
     (ds.floats, {'max_value': 0.0, 'min_value': 1.0}),
+    (ds.floats, {'min_value': 0.0, 'allow_nan': True}),
+    (ds.floats, {'max_value': 0.0, 'allow_nan': True}),
+    (ds.floats, {'min_value': 0.0, 'max_value': 1.0, 'allow_infinity': True}),
     (ds.fixed_dictionaries, {'mapping': 'fish'}),
     (ds.fixed_dictionaries, {'mapping': {1: 'fish'}}),
     (ds.dictionaries, {'keys': ds.integers(), 'values': 1}),
@@ -96,10 +109,16 @@ def test_validates_keyword_arguments(fn, kwargs):
     (ds.integers, {'min_value': 11, 'max_value': 100}),
     (ds.integers, {'max_value': 0}),
     (ds.integers, {'min_value': decimal.Decimal('1.5')}),
-    (ds.integers, {'min_value': fractions.Fraction(1, 2)}),
     (ds.decimals, {'min_value': 1.0, 'max_value': 1.5}),
+    (ds.decimals, {'min_value': '1.0', 'max_value': '1.5'}),
     (ds.decimals, {'min_value': decimal.Decimal('1.5')}),
-    (ds.decimals, {'min_value': fractions.Fraction(1, 3)}),
+    (ds.decimals, {
+        'max_value': 1.0, 'min_value': -1.0, 'allow_infinity': False}),
+    (ds.decimals, {'min_value': 1.0, 'allow_nan': False}),
+    (ds.decimals, {'max_value': 1.0, 'allow_nan': False}),
+    (ds.decimals, {'max_value': 1.0, 'min_value': -1.0, 'allow_nan': False}),
+    (ds.decimals, {'min_value': '-inf'}),
+    (ds.decimals, {'max_value': 'inf'}),
     (ds.fractions, {
         'min_value': -1, 'max_value': 1, 'max_denominator': 1000}),
     (ds.fractions, {'min_value': 1.0}),
@@ -122,6 +141,11 @@ def test_validates_keyword_arguments(fn, kwargs):
     (ds.floats, {'min_value': 1.0}),
     (ds.floats, {'max_value': 1.0}),
     (ds.floats, {'max_value': 1.0, 'min_value': -1.0}),
+    (ds.floats, {
+        'max_value': 1.0, 'min_value': -1.0, 'allow_infinity': False}),
+    (ds.floats, {'min_value': 1.0, 'allow_nan': False}),
+    (ds.floats, {'max_value': 1.0, 'allow_nan': False}),
+    (ds.floats, {'max_value': 1.0, 'min_value': -1.0, 'allow_nan': False}),
     (ds.sampled_from, {'elements': [1]}),
     (ds.sampled_from, {'elements': [1, 2, 3]}),
     (ds.fixed_dictionaries, {'mapping': {1: ds.integers()}}),
@@ -194,7 +218,7 @@ def test_fraction_lt_negative(x):
     assert x <= fractions.Fraction(-1, 2)
 
 
-@given(ds.decimals(min_value=-1.5, max_value=1.5))
+@given(ds.decimals(min_value=-1.5, max_value=1.5, allow_nan=False))
 def test_decimal_is_in_bounds(x):
     # decimal.Decimal("-1.5") == -1.5 (not explicitly testable in py2.6)
     assert decimal.Decimal('-1.5') <= x <= decimal.Decimal('1.5')
@@ -228,7 +252,7 @@ def test_decimals():
 
 
 def test_non_float_decimal():
-    find(ds.decimals(), lambda d: ds.float_to_decimal(float(d)) != d)
+    find(ds.decimals(), lambda d: float_to_decimal(float(d)) != d)
 
 
 def test_produces_dictionaries_of_at_least_minimum_size():
@@ -262,3 +286,15 @@ def test_none_lists_respect_max_size(ls):
 )
 def test_none_lists_respect_max_and_min_size(ls):
     assert 1 <= len(ls) <= 5
+
+
+@given(ds.iterables(ds.integers(), max_size=5, min_size=1))
+def test_iterables_are_exhaustible(it):
+    for _ in it:
+        pass
+    with pytest.raises(StopIteration):
+        next(it)
+
+
+def test_minimal_iterable():
+    assert list(find(ds.iterables(ds.integers()), lambda x: True)) == []
