@@ -3,7 +3,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis-python
 #
-# Most of this work is copyright (C) 2013-2016 David R. MacIver
+# Most of this work is copyright (C) 2013-2017 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -22,7 +22,7 @@ import random
 from pytest import raises
 
 import hypothesis.strategies as st
-from hypothesis import find, given, settings, Verbosity
+from hypothesis import Verbosity, find, given, settings
 
 
 def test_seeds_off_random():
