@@ -3,7 +3,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis-python
 #
-# Most of this work is copyright (C) 2013-2016 David R. MacIver
+# Most of this work is copyright (C) 2013-2017 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -21,12 +21,14 @@ import sys
 from copy import deepcopy
 from functools import partial
 
+import pytest
+
 from tests.common.utils import raises
-from hypothesis.internal.compat import PY3, ArgSpec, getargspec
+from hypothesis.internal.compat import PY3, FullArgSpec, getfullargspec
 from hypothesis.internal.reflection import proxies, arg_string, \
-    copy_argspec, unbind_method, eval_directory, function_digest, \
-    fully_qualified_name, source_exec_as_module, \
-    convert_keyword_arguments, convert_positional_arguments, \
+    unbind_method, eval_directory, function_digest, fully_qualified_name, \
+    source_exec_as_module, convert_keyword_arguments, \
+    define_function_signature, convert_positional_arguments, \
     get_pretty_function_description
 
 
@@ -79,7 +81,7 @@ def test_leaves_unknown_kwargs_in_dict():
 
 def test_errors_on_bad_kwargs():
     def bar():
-        pass    # pragma: no cover
+        pass
 
     with raises(TypeError):
         convert_keyword_arguments(bar, (), {'foo': 1})
@@ -96,14 +98,14 @@ def test_passes_varargs_correctly():
 
 def test_errors_if_keyword_precedes_positional():
     def foo(x, y):
-        pass  # pragma: no cover
+        pass
     with raises(TypeError):
         convert_keyword_arguments(foo, (1,), {'x': 2})
 
 
 def test_errors_if_not_enough_args():
     def foo(a, b, c, d=1):
-        pass  # pragma: no cover
+        pass
 
     with raises(TypeError):
         convert_keyword_arguments(foo, (1, 2), {'d': 4})
@@ -111,7 +113,7 @@ def test_errors_if_not_enough_args():
 
 def test_errors_on_extra_kwargs():
     def foo(a):
-        pass  # pragma: no cover
+        pass
 
     with raises(TypeError) as e:
         convert_keyword_arguments(foo, (1,), {'b': 1})
@@ -170,31 +172,14 @@ def test_names_of_functions_are_pretty():
     ) == 'test_names_of_functions_are_pretty'
 
 
-def test_can_have_unicode_in_lambda_sources():
-    t = lambda x: 'é' not in x
-    assert get_pretty_function_description(t) == (
-        "lambda x: 'é' not in x"
-    )
-
-
-ordered_pair = (
-    lambda right: [].map(
-        lambda length: ()))
-
-
-def test_can_get_descriptions_of_nested_lambdas_with_different_names():
-    assert get_pretty_function_description(ordered_pair) == \
-        'lambda right: [].map(lambda length: ())'
-
-
 class Foo(object):
 
     @classmethod
     def bar(cls):
-        pass  # pragma: no cover
+        pass
 
     def baz(cls):
-        pass  # pragma: no cover
+        pass
 
     def __repr__(self):
         return 'SoNotFoo()'
@@ -215,92 +200,22 @@ def test_class_is_not_included_in_unbound_method():
     )
 
 
-# Note: All of these no branch pragmas are because we don't actually ever want
-# to call these lambdas. We're just inspecting their source.
-
-def test_source_of_lambda_is_pretty():
-    assert get_pretty_function_description(
-        lambda x: True
-    ) == 'lambda x: True'  # pragma: no cover
-
-
-def test_variable_names_are_not_pretty():
-    t = lambda x: True  # pragma: no cover
-    assert get_pretty_function_description(t) == 'lambda x: True'
-
-
-def test_does_not_error_on_dynamically_defined_functions():
-    x = eval('lambda t: 1')
-    get_pretty_function_description(x)
-
-
-def test_collapses_whitespace_nicely():
-    t = (
-        lambda x,       y:           1  # pragma: no cover
-    )
-    assert get_pretty_function_description(t) == 'lambda x, y: 1'
-
-
-def test_is_not_confused_by_tuples():
-    p = (lambda x: x > 1, 2)[0]  # pragma: no cover
-
-    assert get_pretty_function_description(p) == 'lambda x: x > 1'
-
-
 def test_does_not_error_on_confused_sources():
     def ed(f, *args):
         return f
 
     x = ed(
-        lambda x, y: (  # pragma: no cover
+        lambda x, y: (
             x * y
         ).conjugate() == x.conjugate() * y.conjugate(), complex, complex)
 
     get_pretty_function_description(x)
 
 
-def test_strips_comments_from_the_end():
-    t = lambda x: 1  # pragma: no cover
-    assert get_pretty_function_description(t) == 'lambda x: 1'
-
-
-def test_does_not_strip_hashes_within_a_string():
-    t = lambda x: '#'  # pragma: no cover
-    assert get_pretty_function_description(t) == "lambda x: '#'"
-
-
-def test_can_distinguish_between_two_lambdas_with_different_args():
-    a, b = (lambda x: 1, lambda y: 2)  # pragma: no cover
-    assert get_pretty_function_description(a) == 'lambda x: 1'
-    assert get_pretty_function_description(b) == 'lambda y: 2'
-
-
-def test_does_not_error_if_it_cannot_distinguish_between_two_lambdas():
-    a, b = (lambda x: 1, lambda x: 2)  # pragma: no cover
-    assert 'lambda x:' in get_pretty_function_description(a)
-    assert 'lambda x:' in get_pretty_function_description(b)
-
-
-def test_lambda_source_break_after_def_with_brackets():
-    f = (lambda n:
-         'aaa')
-
-    source = get_pretty_function_description(f)
-    assert source == "lambda n: 'aaa'"
-
-
-def test_lambda_source_break_after_def_with_line_continuation():
-    f = lambda n:\
-        'aaa'
-
-    source = get_pretty_function_description(f)
-    assert source == "lambda n: 'aaa'"
-
-
 def test_digests_are_reasonably_unique():
     assert (
         function_digest(test_simple_conversion) !=
-        function_digest(test_does_not_error_on_dynamically_defined_functions)
+        function_digest(test_does_not_error_on_confused_sources)
     )
 
 
@@ -423,42 +338,60 @@ def has_kwargs(**kwargs):
     pass
 
 
-def test_copying_preserves_argspec():
-    for f in [has_one_arg, has_two_args, has_varargs, has_kwargs]:
-        af = getargspec(f)
-        t = copy_argspec('foo', getargspec(f))(universal_acceptor)
-        at = getargspec(t)
-        assert af.args == at.args
-        assert af.varargs == at.varargs
-        assert af.keywords == at.keywords
-        assert len(af.defaults or ()) == len(at.defaults or ())
+@pytest.mark.parametrize('f', [
+    has_one_arg,
+    has_two_args,
+    has_varargs,
+    has_kwargs,
+])
+def test_copying_preserves_argspec(f):
+    af = getfullargspec(f)
+    t = define_function_signature('foo', 'docstring', af)(universal_acceptor)
+    at = getfullargspec(t)
+    assert af.args == at.args
+    assert af.varargs == at.varargs
+    assert af.varkw == at.varkw
+    assert len(af.defaults or ()) == len(at.defaults or ())
+    assert af.kwonlyargs == at.kwonlyargs
+    assert af.kwonlydefaults == at.kwonlydefaults
+    assert af.annotations == at.annotations
 
 
 def test_name_does_not_clash_with_function_names():
     def f():
         pass
 
-    @copy_argspec('f', getargspec(f))
+    @define_function_signature('f', 'A docstring for f', getfullargspec(f))
     def g():
         pass
     g()
 
 
 def test_copying_sets_name():
-    f = copy_argspec(
-        'hello_world', getargspec(has_two_args))(universal_acceptor)
+    f = define_function_signature(
+        'hello_world', 'A docstring for hello_world',
+        getfullargspec(has_two_args))(universal_acceptor)
     assert f.__name__ == 'hello_world'
 
 
+def test_copying_sets_docstring():
+    f = define_function_signature(
+        'foo', 'A docstring for foo',
+        getfullargspec(has_two_args))(universal_acceptor)
+    assert f.__doc__ == 'A docstring for foo'
+
+
 def test_uses_defaults():
-    f = copy_argspec(
-        'foo', getargspec(has_a_default))(universal_acceptor)
+    f = define_function_signature(
+        'foo', 'A docstring for foo',
+        getfullargspec(has_a_default))(universal_acceptor)
     assert f(3, 2) == ((3, 2, 1), {})
 
 
 def test_uses_varargs():
-    f = copy_argspec(
-        'foo', getargspec(has_varargs))(universal_acceptor)
+    f = define_function_signature(
+        'foo', 'A docstring for foo',
+        getfullargspec(has_varargs))(universal_acceptor)
     assert f(1, 2) == ((1, 2), {})
 
 
@@ -486,37 +419,43 @@ def test_exec_leaves_sys_path_unchanged():
     assert sys.path == old_path
 
 
-def test_copy_argspec_works_with_conflicts():
+def test_define_function_signature_works_with_conflicts():
     def accepts_everything(*args, **kwargs):
         pass
 
-    copy_argspec('hello', ArgSpec(
-        args=('f',), varargs=None, keywords=None, defaults=None
+    define_function_signature('hello', 'A docstring for hello', FullArgSpec(
+        args=('f',), varargs=None, varkw=None, defaults=None,
+        kwonlyargs=[], kwonlydefaults=None, annotations={}
     ))(accepts_everything)(1)
 
-    copy_argspec('hello', ArgSpec(
-        args=(), varargs='f', keywords=None, defaults=None
+    define_function_signature('hello', 'A docstring for hello', FullArgSpec(
+        args=(), varargs='f', varkw=None, defaults=None,
+        kwonlyargs=[], kwonlydefaults=None, annotations={}
     ))(accepts_everything)(1)
 
-    copy_argspec('hello', ArgSpec(
-        args=(), varargs=None, keywords='f', defaults=None
+    define_function_signature('hello', 'A docstring for hello', FullArgSpec(
+        args=(), varargs=None, varkw='f', defaults=None,
+        kwonlyargs=[], kwonlydefaults=None, annotations={}
     ))(accepts_everything)()
 
-    copy_argspec('hello', ArgSpec(
-        args=('f', 'f_3'), varargs='f_1', keywords='f_2', defaults=None
+    define_function_signature('hello', 'A docstring for hello', FullArgSpec(
+        args=('f', 'f_3'), varargs='f_1', varkw='f_2', defaults=None,
+        kwonlyargs=[], kwonlydefaults=None, annotations={}
     ))(accepts_everything)(1, 2)
 
 
-def test_copy_argspec_validates_arguments():
+def test_define_function_signature_validates_arguments():
     with raises(ValueError):
-        copy_argspec('hello_world', ArgSpec(
-            args=['a b'], varargs=None, keywords=None, defaults=None))
+        define_function_signature('hello_world', None, FullArgSpec(
+            args=['a b'], varargs=None, varkw=None, defaults=None,
+            kwonlyargs=[], kwonlydefaults=None, annotations={}))
 
 
-def test_copy_argspec_validates_function_name():
+def test_define_function_signature_validates_function_name():
     with raises(ValueError):
-        copy_argspec('hello world', ArgSpec(
-            args=['a', 'b'], varargs=None, keywords=None, defaults=None))
+        define_function_signature('hello world', None, FullArgSpec(
+            args=['a', 'b'], varargs=None, varkw=None, defaults=None,
+            kwonlyargs=[], kwonlydefaults=None, annotations={}))
 
 
 class Container(object):
