@@ -3,7 +3,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis-python
 #
-# Most of this work is copyright (C) 2013-2016 David R. MacIver
+# Most of this work is copyright (C) 2013-2017 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -24,7 +24,7 @@ import pytest
 
 from hypothesis import given, reporting
 from tests.common.utils import capture_out
-from hypothesis._settings import settings, Verbosity
+from hypothesis._settings import Verbosity, settings
 from hypothesis.reporting import report, debug_report, verbose_report
 from hypothesis.strategies import integers
 from hypothesis.internal.compat import PY2
