@@ -3,7 +3,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis-python
 #
-# Most of this work is copyright (C) 2013-2016 David R. MacIver
+# Most of this work is copyright (C) 2013-2017 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -21,32 +21,32 @@ import pytz
 
 import hypothesis._settings as hs
 from hypothesis import given, assume
-from hypothesis.strategytests import strategy_test_suite
+from tests.common.debug import minimal
+from tests.common.utils import checks_deprecated_behaviour
 from hypothesis.extra.datetime import times
-from hypothesis.internal.debug import minimal
-
-TestStandardDescriptorFeatures1 = strategy_test_suite(times())
 
 
+@checks_deprecated_behaviour
 def test_can_find_midnight():
-    minimal(
-        times(),
-        lambda x: (x.hour == 0 and x.minute == 0 and x.second == 0),
-    )
+    times().filter(lambda x: x.hour == x.minute == x.second == 0).example()
 
 
+@checks_deprecated_behaviour
 def test_can_find_non_midnight():
     assert minimal(times(), lambda x: x.hour != 0).hour == 1
 
 
+@checks_deprecated_behaviour
 def test_can_find_off_the_minute():
-    minimal(times(), lambda x: x.second == 0)
+    times().filter(lambda x: x.second != 0).example()
 
 
+@checks_deprecated_behaviour
 def test_can_find_on_the_minute():
-    minimal(times(), lambda x: x.second != 0)
+    times().filter(lambda x: x.second == 0).example()
 
 
+@checks_deprecated_behaviour
 def test_simplifies_towards_midnight():
     d = minimal(times())
     assert d.hour == 0
@@ -55,22 +55,25 @@ def test_simplifies_towards_midnight():
     assert d.microsecond == 0
 
 
+@checks_deprecated_behaviour
 def test_can_generate_naive_time():
-    minimal(times(allow_naive=True), lambda d: not d.tzinfo)
+    times(allow_naive=True).filter(lambda d: d.tzinfo is not None).example()
 
 
+@checks_deprecated_behaviour
 def test_can_generate_non_naive_time():
     assert minimal(
         times(allow_naive=True), lambda d: d.tzinfo).tzinfo == pytz.UTC
 
 
+@checks_deprecated_behaviour
 def test_can_generate_non_utc():
-    minimal(
-        times(),
-        lambda d: assume(d.tzinfo) and d.tzinfo.zone != u'UTC')
+    times().filter(
+        lambda d: assume(d.tzinfo) and d.tzinfo.zone != u'UTC'
+    ).example()
 
 
-with hs.settings(max_examples=1000):
+with hs.settings(strict=False):
     @given(times(timezones=[]))
     def test_naive_times_are_naive(dt):
         assert not dt.tzinfo
@@ -80,6 +83,7 @@ with hs.settings(max_examples=1000):
         assert dt.tzinfo
 
 
+@checks_deprecated_behaviour
 def test_restricts_to_allowed_set_of_timezones():
     timezones = list(map(pytz.timezone, list(pytz.all_timezones)[:3]))
     x = minimal(times(timezones=timezones))
