@@ -3,7 +3,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis-python
 #
-# Most of this work is copyright (C) 2013-2016 David R. MacIver
+# Most of this work is copyright (C) 2013-2017 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -18,12 +18,12 @@
 from __future__ import division, print_function, absolute_import
 
 from django.contrib import admin
-from django.conf.urls import url, include, patterns
+from django.conf.urls import url, include
 
-urlpatterns = patterns(u'',
-                       # Examples:
-                       # url(r'^$', 'toys.views.home', name='home'),
-                       # url(r'^blog/', include('blog.urls')),
+urlpatterns = [
+    # Examples:
+    # url(r'^$', 'toys.views.home', name='home'),
+    # url(r'^blog/', include('blog.urls')),
 
-                       url(r'^admin/', include(admin.site.urls)),
-                       )
+    url(r'^admin/', include(admin.site.urls)),
+]
