@@ -3,7 +3,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis-python
 #
-# Most of this work is copyright (C) 2013-2016 David R. MacIver
+# Most of this work is copyright (C) 2013-2017 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -17,6 +17,8 @@
 
 from __future__ import division, print_function, absolute_import
 
+from django.conf import settings as django_settings
+
 from hypothesis import given, assume
 from hypothesis.errors import InvalidArgument
 from hypothesis.strategies import just, lists
@@ -56,6 +58,13 @@ class TestGetsBasicModels(TestCase):
         self.assertIsNotNone(customer.pk)
         self.assertIsNotNone(customer.email)
 
+    @given(models(Customer))
+    def test_tz_presence(self, customer):
+        if django_settings.USE_TZ:
+            self.assertIsNotNone(customer.birthday.tzinfo)
+        else:
+            self.assertIsNone(customer.birthday.tzinfo)
+
     @given(models(CouldBeCharming))
     def test_is_not_charming(self, not_charming):
         self.assertIsInstance(not_charming, CouldBeCharming)
