@@ -3,7 +3,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis-python
 #
-# Most of this work is copyright (C) 2013-2016 David R. MacIver
+# Most of this work is copyright (C) 2013-2017 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -23,7 +23,6 @@ from flaky import flaky
 
 import hypothesis.strategies as st
 from hypothesis import find, given, example, settings
-from hypothesis.internal.debug import timeout
 from hypothesis.internal.compat import integer_types
 
 
@@ -130,7 +129,6 @@ def test_can_form_sets_of_recursive_data():
 
 @given(st.randoms())
 @settings(max_examples=2, database=None)
-@timeout(60)
 def test_can_flatmap_to_recursive_data(rnd):
     stuff = st.lists(st.integers(), min_size=1).flatmap(
         lambda elts: st.recursive(
