@@ -3,7 +3,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis-python
 #
-# Most of this work is copyright (C) 2013-2016 David R. MacIver
+# Most of this work is copyright (C) 2013-2017 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -21,14 +21,13 @@ import math
 import hashlib
 from random import Random
 
-from hypothesis import seed, given, assume, settings, Verbosity
+from hypothesis import Verbosity, seed, given, assume, settings
 from hypothesis.errors import NoExamples, FailedHealthCheck
 from hypothesis.database import ExampleDatabase
-from hypothesis.stateful import rule, Bundle, RuleBasedStateMachine
+from hypothesis.stateful import Bundle, RuleBasedStateMachine, rule
 from hypothesis.strategies import just, none, text, lists, binary, \
     floats, tuples, booleans, decimals, integers, fractions, \
     float_to_int, int_to_float, sampled_from, complex_numbers
-from hypothesis.internal.debug import timeout
 from hypothesis.internal.compat import PYPY
 
 AVERAGE_LIST_LENGTH = 2
@@ -62,10 +61,6 @@ class HypothesisSpec(RuleBasedStateMachine):
     def teardown(self):
         self.clear_database()
 
-    @timeout(60, catchable=True)
-    def execute_step(self, step):
-        return super(HypothesisSpec, self).execute_step(step)
-
     @rule()
     def clear_database(self):
         if self.database is not None:
@@ -77,13 +72,13 @@ class HypothesisSpec(RuleBasedStateMachine):
         self.teardown()
         self.database = ExampleDatabase()
 
-    @rule(strat=strategies, r=integers(), mshr=integers(0, 100))
-    def find_constant_failure(self, strat, r, mshr):
+    @rule(strat=strategies, r=integers(), max_shrinks=integers(0, 100))
+    def find_constant_failure(self, strat, r, max_shrinks):
         with settings(
             verbosity=Verbosity.quiet, max_examples=1,
             min_satisfying_examples=0,
             database=self.database,
-            max_shrinks=mshr,
+            max_shrinks=max_shrinks,
         ):
             @given(strat)
             @seed(r)
@@ -97,14 +92,14 @@ class HypothesisSpec(RuleBasedStateMachine):
 
     @rule(
         strat=strategies, r=integers(), p=floats(0, 1),
-        mex=integers(1, 10), mshr=integers(1, 100)
+        max_examples=integers(1, 10), max_shrinks=integers(1, 100)
     )
-    def find_weird_failure(self, strat, r, mex, p, mshr):
+    def find_weird_failure(self, strat, r, max_examples, p, max_shrinks):
         with settings(
-            verbosity=Verbosity.quiet, max_examples=mex,
+            verbosity=Verbosity.quiet, max_examples=max_examples,
             min_satisfying_examples=0,
             database=self.database,
-            max_shrinks=mshr,
+            max_shrinks=max_shrinks,
         ):
             @given(strat)
             @seed(r)
